context("canvasXpress Web Charts - Line")


test_that("cXline1", {
    check_ui_test(cXline1())
})

test_that("cXline2", {
    check_ui_test(cXline2())
})

test_that("cXline3", {
    check_ui_test(cXline3())
})

test_that("cXline4", {
    check_ui_test(cXline4())
})
